#include <bits/stdc++.h>
using namespace std;

struct Point {
    long long x, y;

    Point(long long int x, long long int y) : x(x), y(y) {}

    Point() {}

    Point operator-(Point p) {
        return Point(x - p.x, y - p.y);
    }
};

inline long long cross(Point p1, Point p2) {
    return p1.x * p2.y - p1.y * p2.x;
}

inline long long dot(Point p1, Point p2) {
    return p1.x * p2.x + p1.y * p2.y;
}

inline int sign(long long x) {
    if (x < 0) return -1;
    if (x > 0) return 1;
    return 0;
}

struct cmp {
    bool operator()(const Point &a, const Point &b) {
        if (a.x != b.x) {
            return a.x < b.x;
        } else {
            return a.y < b.y;
        }
    }
};

long long gcd(long long a, long long b) {
    if (b == 0) return a;
    return gcd(b, a % b);
}

Point norm(Point a) {
    long long g = gcd(a.x, a.y);
    a.x /= g;
    a.y /= g;

    if (a.y < 0) {
        a.x *= -1;
        a.y *= -1;
    } else if (a.y == 0 && a.x < 0) {
        a.x *= -1;
    }

    return a;
}

inline bool in(Point a, Point b, Point c) {
    return dot(a - b, c - b) > 0 && dot(b - a, c - a) > 0;
}

inline bool mem(Point a, Point b, Point c, Point d) {
    return dot(b - a, c - a) == 0 && dot(a - b, d - b) == 0;
}

inline bool ok(Point a, Point b, Point c, Point d) {
    if (cross(b - a, d - c) != 0) {
        return false;
    }
    return in(a, b, c) || in(a, b, d) || in(c, d, a) || in(c, d, b) || mem(a, b, c, d) || mem(a, b, d, c);
}

int n;
int m;
vector<Point> a, b;

bool check(int sa, int sb) {
    if (!ok(a[sa], a[(sa + 1) % a.size()], b[sb], b[(sb + 1) % b.size()])) {
        return false;
    }

    Point pa = a[(sa + 2) % a.size()];
    Point pb = b[(sb + 2) % b.size()];

    Point va = a[(sa + 1) % a.size()] - a[sa];
    Point vb = b[(sb + 1) % b.size()] - b[sb];
    if (sign(cross(va, b[sb] - a[sa])) == sign(cross(va, pa - a[sa]))) {
        return false;
    }
    if (sign(cross(vb, a[sa] - b[sb])) == sign(cross(vb, pb - b[sb]))) {
        return false;
    }
    return true;
}

int main() {
#ifdef DEBUG
    freopen("input", "r", stdin);
#endif
    ios::sync_with_stdio(0);
    cin.tie(0);

    cin >> n;
    a.resize(n);
    for (int i = 0; i < n; i++) {
        cin >> a[i].x >> a[i].y;
    }
    cin >> m;
    b.resize(m);
    for (int i = 0; i < m; i++) {
        cin >> b[i].x >> b[i].y;
    }

    map<Point, vector<int>, cmp> sides;
    for (int i = 0; i < n; i++) {
        auto s = norm(a[(i + 1) % n] - a[i]);
        sides[s].push_back(i);
    }
    for (int i = 0; i < m; i++) {
        auto s = norm(b[(i + 1) % m] - b[i]);
        sides[s].push_back(n + i);
    }

    for (auto &p : sides) {
        auto &ss = p.second;
        for (int i : ss) {
            for (int j : ss) {
                if (i < n && j >= n) {
                    int sa = i;
                    int sb = j - n;

                    if (check(sa, sb)) {
                        cout << "YES" << endl;
                        cout << sa + 1 << " " << sb + 1 << endl;
                        return 0;
                    }
                }
            }
        }
    }

    cout << "NO" << endl;

    return 0;
}