#include <iostream>
#include <vector>
#include <algorithm>
#include <queue>
#include <tuple>

using namespace std;

const int sparseDepth = 18;

class SparseTable {
private:
    int n;
    vector< vector<int64_t> > a;
    vector<int> lg;
public:
    inline int64_t rmq(int l, int r) {
        int w = lg[r - l + 1];
        return min(a[w][l], a[w][r - (1 << w) + 1]);
    }

    SparseTable(vector<int64_t> v) :
        n(v.size()), a(sparseDepth, vector<int64_t>(n)), lg(n+1) {
        lg[1] = 0;
        for (int i = 2; i <= n; i++) {
            lg[i] = lg[i/2] + 1;
            for (int i = 0; i < n; i++) {
                a[0][i] = v[i];
            }
            for (int i = 1; i < sparseDepth; i++) {
                for (int j = 0; j <= n - (1 << i); j++) {
                    a[i][j] = min(a[i-1][j], a[i-1][j + (1 << (i-1))]);
                }
            }
        }
    }
};

signed main() {
    ios_base::sync_with_stdio(false);

    vector< pair<int, int> > sss(3);
    for (int i = 0; i < 3; i++) {
        cin >> sss[i].first >> sss[i].second;
    }
    sort(sss.begin(), sss.end());

    int a, nA, b, nB, c, nC;
    tie(a, nA) = sss[0];
    tie(b, nB) = sss[1];
    tie(c, nC) = sss[2];

    int n; cin >> n;
    vector<int> v(n);
    for (int i = 0; i < n; i++) {
        cin >> v[i];
    }
    sort(v.begin(), v.end());

    vector<int64_t> pd0(n+1), pd1(n+1), pd2(n+1);
    for (int i = 0; i < n; i++) {
        pd0[i+1] = pd0[i] + abs(v[i] - a);
        pd1[i+1] = pd1[i] + abs(v[i] - b);
        pd2[i+1] = pd2[i] + abs(v[i] - c);
    }

    vector<int64_t> q(n+1);
    for (int i = 0; i <= n; i++) {
        q[i] = pd1[i] + pd2[n] - pd2[i];
    }

    /*for (int i = 0; i <= n; i++) {
        cout << pd0[i] << " ";
    }
    cout << endl;
    for (int i = 0; i <= n; i++) {
        cout << pd1[i] << " ";
    }
    cout << endl;
    for (int i = 0; i <= n; i++) {
        cout << pd2[i] << " ";
    }
    cout << endl;
    for (int i = 0; i <= n; i++) {
        cout << q[i] << " ";
    }
    cout << endl;*/

    SparseTable st(q);

    int64_t ans = 123456789012345678LL;

    for (int i = 0; i <= n && i <= nA; i++) {
        int l = n - i - nB, r = nC;
        swap(l, r);
        l = n - l; r = n - r;
        l = max(l, i);
        r = min(r, n);

        //cout << i << " : " << l << " " << r << endl;

        if (l > r) {
            continue;
        }

        //cout << "!!! " << q[3] << " " << st.rmq(1, 3) << " " << pd1[i] << " " << pd0[i] << endl;

        ans = min(ans, st.rmq(l, r) - pd1[i] + pd0[i]);
    }

    cout << ans << endl;
    return 0;
}
