#include <iostream>
#include <vector>
#include <algorithm>
#include <map>
#include <climits>
#define int int64_t

using namespace std;

template<typename T>
class Fenwick {
private:
    int n;
    T def;
    vector<T> f;
public:
    inline void modify(int v, T newVal) {
        for (; v < n; v |= v+1) {
            f[v] = min(f[v], newVal);
        }
    }

    inline T query(int v) {
        T val = def;
        for (; v >= 0; v &= v+1, v--) {
            val = min(val, f[v]);
        }
        return val;
    }

    Fenwick(int n, T def) :
        n(n), def(def), f(n, def) {
    }

    Fenwick() {
    }
};

#undef LLONG_MAX
#define LLONG_MAX 4611686018427387902LL

signed main() {
    static int64_t dp[3000][3000] = {};
    static int pp[3000][3000] = {};
    static int dc[3000][3000] = {};
    int n, m; cin >> n >> m;
    vector<int64_t> d(n), c(n), p(n);
    for (int i = 0; i < n; i++) {
        cin >> d[i] >> c[i] >> p[i];
        if (c[i] > m) {
            c[i] = m;
        }
        d[i] *= -1;
    }
    for (int i = 0; i <= n; i++) {
        for (int j = 0; j <= m; j++) {
            dp[i][j] = LLONG_MAX;
        }
    }
    map<int64_t, int> kompr;
    for (int i = 0; i < n; i++) {
        kompr[d[i]] = 42;
    }
    int komptr = 0;
    for (auto &it : kompr) {
        it.second = komptr++;
    }
    for (int i = 0; i < n; i++) {
        d[i] = kompr[d[i]];
    }

    vector< Fenwick< pair<int64_t, int> > > ff(m+1, Fenwick< pair<int64_t, int> >(komptr, make_pair(LLONG_MAX, -1)));

    ff[0].modify(0, make_pair(0, -1));

    for (int i = 0; i < n; i++) {
        for (int j = 0; j <= m; j++) {
            dp[i][j] = LLONG_MAX;
            pp[i][j] = -1;
            dc[i][j] = 0;
            int k = j - c[i];
            if (k < 0) {
                continue;
            }
            auto it = ff[k].query(d[i]);
            dp[i][j] = it.first;
            pp[i][j] = it.second;
            if (dp[i][j] < LLONG_MAX) {
                dp[i][j] += p[i];
            }
            dc[i][j] = 0;
        }
        for (int j = m-1; j >= 0; j--) {
            if (dp[i][j] > dp[i][j+1]) {
                dp[i][j] = dp[i][j+1];
                pp[i][j] = pp[i][j+1];
                dc[i][j] = dc[i][j+1] + 1;
            }
        }
        for (int j = 0; j <= m; j++) {
            ff[j].modify(d[i], make_pair(dp[i][j], i));
            //cout << "(" << dp[i][j] << ", " << pp[i][j] << ", " << dc[i][j] << ") ";
        }
        //cout << endl;
    }

    int minI = 0;
    for (int i = 1; i < n; i++) {
        if (dp[i][m] < dp[minI][m]) {
            minI = i;
        }
    }

    if (dp[minI][m] >= LLONG_MAX) {
        cout << -1 << endl;
        return 0;
    }

    int qI = minI, qJ = m;
    vector<int> ans;
    while (qI >= 0) {
        qJ += dc[qI][qJ];
        ans.push_back(qI+1);
        qJ -= c[qI];
        qI = pp[qI][qJ + c[qI]];
    }

    reverse(ans.begin(), ans.end());
    cout << dp[minI][m] << " " << ans.size() << endl;
    for (int i : ans) {
        cout << i << " ";
    }
    cout << endl;

    return 0;
}
