#include <iostream>
#include <string>
#include <vector>
#include <algorithm>
#define re system("pause"); return 0;
using namespace std;

typedef long long ll;
typedef long double ld;

const ll mod = (ll)1e9 + 7;
const ld eps = 1e-6;

struct point
{
	ld x = 0, y = 0;
	point() {}
	point(ld xx, ld yy)
	{
		x = xx;
		y = yy;
	}
	point operator*(ld c) {
		return point(x * c, y * c);
	}
	point operator+(point t) {
		return point(x + t.x, y + t.y);
	}
	point operator-(point t) {
		return point(x - t.x, y - t.y);
	}
	bool operator==(point p)
	{
		return (fabs(x - p.x) < eps && fabs(y - p.y) < eps);
	}
};

struct line {
	ld a = 0, b = 0, c = 0;
	int id;
	line() {}
	line(point p1, point p2) {
		a = p1.y - p2.y;
		b = p2.x - p1.x;
		c = -a * p1.x - b * p1.y;
		ld x = sqrt(a * a + b * b);
		a /= x;
		b /= x;
		c /= x;
		if (a < eps)
		{
			a = -a;
			b = -b;
			c = -c;
		}
		if (a < eps && a > -eps) {
			if (b < eps)
			{
				a = -a;
				b = -b;
				c = -c;
			}
		}
	}
	bool operator<(line l) {
		if (fabs(a - l.a) > eps)
			return a - eps < l.a;
		if (fabs(b - l.b) > eps)
			return b - eps < l.b;
		return c - eps < l.c;
	}
	bool ispar(line l) {
		return fabs(a - l.a) < eps && fabs(b - l.b) < eps;
	}
	ld dist(point p) {
		return fabs(a * p.x + b * p.y + c);
	}
};

bool intersect(point a1, point a2, point b1, point b2) {
	if (a1.x > a2.x)
		swap(a1, a2);
	if (b1.x > b2.x)
		swap(b1, b2);
	if (a1 == b2 || a2 == b1)
		return 0;
	if (a1.x - eps < b1.x && b1.x - eps< a2.x || a1.x - eps< b2.x && b2.x - eps< a2.x) {
		if (a1.y - eps < b1.y && b1.y - eps< a2.y || a1.y - eps< b2.y && b2.y - eps< a2.y)
			return 1;
	}
	return 0;
}

vector <point> p1, p2;

int main() {
	int n, m;
	cin >> n;
	p1.resize(n);
	for (int i = 0; i < n; i++)
	{
		cin >> p1[i].x >> p1[i].y;
	}
	p1.push_back(p1[0]);
	cin >> m;
	p2.resize(m);
	for (int i = 0; i < m; i++)
	{
		cin >> p2[i].x >> p2[i].y;
	}
	p2.push_back(p2[0]);
	vector <line> l1, l2;
	for (int i = 0; i < n; i++) {
		l1.push_back(line(p1[i], p1[i + 1]));
		l1.back().id = i;
	}
	for (int i = 0; i < m; i++) {
		l2.push_back(line(p2[i], p2[i + 1]));
		l2.back().id = i;
	}
	sort(l1.begin(), l1.end());
	sort(l2.begin(), l2.end());
	int j = 0;
	for (int i = 0; i < l1.size(); i++) {
		for (j = 0; j < l2.size(); j++) {
			if (l1[i].ispar(l2[j])) {
				line lin = l1[i];
				point pp1 = p2[l2[j].id];
				point pp2 = p2[l2[j].id + 1];
				point pn = point(lin.a, lin.b);
				pn = pn * lin.dist(pp1);
				pp1 = pp1 + pn;
				pp2 = pp2 + pn;
				if (lin.dist(pp1) > eps)
					pp1 = pp1 - pn * 2, pp2 = pp2 - pn * 2;
				point mid = (pp1 + pp2) * 0.5;
				bool f = intersect(pp1, mid, p1[lin.id], p1[lin.id + 1]) || intersect(pp2, mid, p1[lin.id], p1[lin.id + 1]);
				if (f) {
					cout << "YES\n" << lin.id + 1 << ' ' << l2[j].id + 1 << '\n';
					re;
				}
			}
		}
	}
	cout << "NO\n";
	re
}

/*

3
0 0
1 0
0 1
3
0 -1
0 -2
1 -1

3
0 0
1 0
0 1
3
1 -1
1 -2
2 -1


4
-1 0
0 0
0 1
-1 1
4
1 0
0 -1
1 -2
2 -1
*/