import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.*;

public class pandemy2_vd {

    enum EventType {
        INFECTED_EDGE_BOTH,
        INFECTED_EDGE_SINGLE_END,
        INFECTED_VERTEX
    }

    class Event implements Comparable<Event>
    {
        public Event(long time, EventType eventType)
        {
            this.time = time;
            this.eventType = eventType;
            isCancelled = false;
            vertex = -1;
        }

        public Event(long time, EventType eventType, int vertex)
        {
            this(time, eventType);
            this.vertex = vertex;
        }

        long time;
        boolean isCancelled;
        EventType eventType;
        int vertex;


        @Override
        public int compareTo(Event o) {
            if (o.time == time)
            {
                return eventType.compareTo(o.eventType);
            }
            return Long.compare(time, o.time);
        }
    }


    class Edge
    {
        public Edge(int u, int v, long l)
        {
            this.u = u;
            this.v = v;
            this.l = 2*l;
            wasBurn = false;
            infectedEvent = null;
        }

        int u, v;
        long l;

        boolean wasBurn;
        Event infectedEvent;

        public Event fire(long currentTime, int vertex)
        {
            if (infectedEvent == null)
            {
                infectedEvent = new Event(currentTime+l, EventType.INFECTED_EDGE_SINGLE_END, (vertex == v) ? u : v);
            }
            else
            {
                infectedEvent.isCancelled = true;
                long left = (currentTime - (infectedEvent.time - l));
                infectedEvent = new Event(currentTime+(l - left) / 2, EventType.INFECTED_EDGE_BOTH);
            }
            return infectedEvent;
        }

        public boolean isWasBurn(long currentTime) {
            return (infectedEvent != null && infectedEvent.time <= currentTime);
        }
    }

    public long solve(int[] u, int[] v, long[] l, int[] a)
    {
        int n = u.length+1;
        ArrayList<Edge>[] edges = new ArrayList[n];
        for (int i = 0; i < n; i++)
        {
            edges[i] = new ArrayList<>();
        }
        for (int i = 0; i < n-1; i++)
        {
            Edge e = new Edge(u[i]-1, v[i] - 1, l[i]);
            edges[e.u].add(e);
            edges[e.v].add(e);
        }
        int m = a.length;
        PriorityQueue<Event> event_queue = new PriorityQueue<>();
        for (int i = 0; i < m; i++)
        {
            event_queue.add(new Event(0, EventType.INFECTED_VERTEX, a[i]-1));
        }
        boolean[] isInfected = new boolean[n];

        long prevTime = -1;
        int currentComp = 1;
        int maxComp = 1;

        while (event_queue.size() > 0)
        {
            Event cur = event_queue.poll();

            if (cur.isCancelled)
            {
                continue;
            }

            if (prevTime  < cur.time)
            {
                maxComp = Math.max(currentComp, maxComp);
            }

            switch (cur.eventType)
            {
                case INFECTED_EDGE_BOTH:
                    currentComp--;
                    break;
                case INFECTED_EDGE_SINGLE_END:
                    event_queue.add(new Event(cur.time, EventType.INFECTED_VERTEX, cur.vertex));
                    break;
                case INFECTED_VERTEX:
                    if (isInfected[cur.vertex])
                        break;
                    isInfected[cur.vertex] = true;
                    currentComp--;
                    for (Edge e : edges[cur.vertex])
                    {
                        if (!e.isWasBurn(cur.time))
                        {
                            currentComp++;
                            event_queue.add(e.fire(cur.time, cur.vertex));
                        }
                    }
                    break;
            }
            prevTime = cur.time;
        }
        return maxComp;
    }

    public void solve() throws IOException {
        int n = nextInt();
        int[] u = new int[n-1];
        int[] v = new int[n-1];
        long[] l = new long[n-1];
        for (int i = 0; i < n - 1; i++)
        {
            u[i] = nextInt();
            v[i] = nextInt();
            l[i] = nextLong();
        }
        int m = nextInt();
        int[] a = new int[m];
        for (int i = 0; i < m; i++)
        {
            a[i] = nextInt();
        }
        out.println(solve(u,v,l,a));
    }


    public static void main(String[] args) throws IOException {
        new pandemy2_vd().run();
    }

    public void run() throws IOException {
        in = new BufferedReader(new InputStreamReader(System.in));
        out = new PrintWriter(System.out);
        solve();
        out.close();
    }

    BufferedReader in;
    PrintWriter out;
    StringTokenizer st;

    public String next() throws IOException {
        while (st == null || !st.hasMoreElements()) {
            st = new StringTokenizer(in.readLine());
        }
        return st.nextToken();
    }

    public Long nextLong() throws IOException {
        return Long.parseLong(next());
    }

    public Integer nextInt() throws IOException {
        return Integer.parseInt(next());
    }

}