import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.PriorityQueue;
import java.util.StringTokenizer;

public class pandemy2_vd_cute {

    class Event
    {
        public Event(long time, boolean isForEdge, int vertex)
        {
            this.time = time;
            this.isForEdge = isForEdge;
            isCancelled = false;
            this.vertex = vertex;
        }

        long time;
        boolean isCancelled;
        boolean isForEdge;
        int vertex;
    }

    class Edge
    {
        public Edge(int u, int v, long l)
        {
            this.u = u;
            this.v = v;
            this.l = 2*l;
            wasBurn = false;
            infectedEvent = null;
        }

        int u, v;
        long l;

        boolean wasBurn;
        Event infectedEvent;

        public Event fire(long currentTime, int vertex)
        {
            if (infectedEvent == null)
            {
                infectedEvent = new Event(currentTime+l, false, (vertex == v) ? u : v);
            }
            else
            {
                infectedEvent.isCancelled = true;
                long left = (currentTime - (infectedEvent.time - l));
                infectedEvent = new Event(currentTime+(l - left) / 2, true, -1);
            }
            return infectedEvent;
        }
    }

    public void solve() throws IOException {
        int n = nextInt();
        ArrayList<Edge>[] edges = new ArrayList[n];
        for (int i = 0; i < n; i++)
        {
            edges[i] = new ArrayList<>();
        }
        for (int i = 0; i < n-1; i++)
        {
            Edge e = new Edge(nextInt()-1, nextInt() - 1, nextInt());
            edges[e.u].add(e);
            edges[e.v].add(e);
        }
        int m = nextInt();
        PriorityQueue<Event> event_queue = new PriorityQueue<>((o1, o2)-> o1.time != o2.time ? Long.compare(o1.time, o2.time) : Boolean.compare(o1.isForEdge, o2.isForEdge));
        for (int i = 0; i < m; i++)
        {
            event_queue.add(new Event(0, false, nextInt()-1));
        }

        long prevTime = -1;
        int currentComp = 1;
        int maxComp = 1;

        while (event_queue.size() > 0)
        {
            Event cur = event_queue.poll();

            if (cur.isCancelled)
            {
                continue;
            }

            if (prevTime  < cur.time)
            {
                maxComp = Math.max(currentComp, maxComp);
            }

            currentComp--;

            if (cur.isForEdge)
            {
                continue;
            }

            for (Edge e : edges[cur.vertex])
            {
                currentComp++;
                event_queue.add(e.fire(cur.time, cur.vertex));
            }

            prevTime = cur.time;
        }
        out.println(maxComp);
    }

    public static void main(String[] args) throws IOException {
        new pandemy2_vd_cute().run();
    }

    public void run() throws IOException {
        in = new BufferedReader(new InputStreamReader(System.in));
        out = new PrintWriter(System.out);
        solve();
        out.close();
    }

    BufferedReader in;
    PrintWriter out;
    StringTokenizer st;

    public String next() throws IOException {
        while (st == null || !st.hasMoreElements()) {
            st = new StringTokenizer(in.readLine());
        }
        return st.nextToken();
    }

    public Long nextLong() throws IOException {
        return Long.parseLong(next());
    }

    public Integer nextInt() throws IOException {
        return Integer.parseInt(next());
    }

}